# eric7.WebBrowser.Network.UrlInterceptor

Module implementing an URL interceptor base class.

### Global Attributes

None

### Classes

UrlInterceptor | Class implementing an URL interceptor base class.

### Functions

None

## UrlInterceptor

Class implementing an URL interceptor base class.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

UrlInterceptor | Constructor
interceptRequest | Public method to intercept a request.

### Static Methods

None

#### UrlInterceptor (Constructor)

UrlInterceptor(parent=None)

Constructor

parent (QObject)
  referemce to the parent object

#### UrlInterceptor.interceptRequest

interceptRequest(info)

Public method to intercept a request.

info (QWebEngineUrlRequestInfo)
  request info object

Up